/*
  great.h

  For Tux Paint
  Collection of congratulatory strings (like "Great!").

  Copyright (c) 2002 by Bill Kendrick
  bill@newbreedsoftware.com
  http://www.newbreedsoftware.com/tuxpaint/

  September 28, 2002 - September 30, 2002
*/


#ifndef GREAT_H
#define GREAT_H


const char * const great_strs[] = {
  gettext_noop("Great!"),
  gettext_noop("Cool!"),
  gettext_noop("Keep it up!"),
  gettext_noop("Good job!")
};

#endif /* GREAT_H */
